@@ -8,7 +8,7 @@ use Crypt::CBC;
 use MIME::Base64;
 use Exporter;
 use vars qw($VERSION @EXPORT_OK @ISA);
-$VERSION = '1.1.4';
+$VERSION = '1.1';
 @ISA = ('Exporter');
 @EXPORT_OK = qw(dmac hexdigest base64digest);
 
@@ -40,11 +40,7 @@ sub dmac
 
     $cipher = $cipher=~/^Crypt::/ ? $cipher : "Crypt::$cipher";
     eval "require $cipher";
-    if ($@) {
-        print "Can't load cipher $cipher.\n";
-        print "You must install $cipher first!\n";
-        exit 0;
-    }
+    croak "Couldn't load $cipher: $@" if ($@);
 
     $cipher =~ s/^Crypt::// unless $cipher->can('blocksize');
 
@@ -83,80 +79,52 @@ __END__
 
 =head1 NAME
 
-Digest::DMAC
-
-=head1 REVISION
-
-Please use Digest::EMAC instead. EMAC is now the official name of
-Double CBC MAC.
+Digest::DMAC 1.0
 
 =head1 EXAMPLE 1
 
-    use Digest::DMAC qw(dmac hexdigest base64digest);
+use Crypt::CBC;
 
-    print "Enter key: ";
-    my $key = <STDIN>;
-    chomp $key;
+use Digest::DMAC qw(dmac hexdigest base64digest);
 
-    print "Enter cipher: ";
-    my $cipher = <STDIN>;
-    chomp $cipher;
+my $key = "jcd";
 
-    print "Enter string: ";
-    my $str = <STDIN>;
-    chomp $str;
+my $cipher = "Serpent";
 
-    my $mac = dmac($key, $cipher, $str);
-    print hexdigest($mac), "\n";
-    print base64digest($mac), "\n";
+my $data = "This is a test";
+
+my $mac = &dmac($key, $cipher, $data);
+
+print hexdigest($mac), "\n";
+
+print base64digest($mac), "\n";
 
 =head1 EXAMPLE 2
 
-    use Digest::DMAC qw(dmac hexdigest base64digest);
+use Crypt::CBC;
 
-    print "Enter key: ";
-    my $key = <STDIN>;
-    chomp $key;
+use Digest::DMAC qw(dmac hexdigest base64digest);
 
-    print "Enter cipher: ";
-    my $cipher = <STDIN>;
-    chomp $cipher;
+local $/ = undef;    # slurp whole file
 
-    print "Enter file: ";
-    my $infile = <STDIN>;
-    chomp $infile;
-    local $/ = undef;
-    open F, $infile;
-    my $data = <F>;
+$infile = "../DMAC.pm";
 
-    my $mac = dmac($key, $cipher, $data);
-    close F;
-    print hexdigest($mac), "\n";
-    print base64digest($mac), "\n";
+open F, $infile;
 
-=head1 EXAMPLE 3
+while (<F>) {
 
-    use Digest::DMAC qw(dmac hexdigest base64digest);
+    $mac1 = &dmac($key, $cipher, $_);
+}
 
-    print "Enter key: ";
-    my $key = <STDIN>;
-    chomp $key;
+print hexdigest($mac1), "\n";
 
-    print "Enter cipher: ";
-    my $cipher = <STDIN>;
-    chomp $cipher;
-    local $/ = undef;
-
-    while (<>) {
-        my $mac = dmac($key, $cipher, $_);
-        print hexdigest($mac), "\n";
-    }
+print base64digest($mac1), "\n";
 
 =head1 DESCRIPTION
 
-This is B<Encrypted MAC> (B<EMAC>), also known as B<Double MAC>
-(B<DMAC>). Unlike B<HMAC>, which reuses an existing one-way hash
-function, such as B<MD5>, B<SHA-1> or B<RIPEMD-160>, EMAC reuses an
+This is B<Double MAC> (B<DMAC>), also known as B<Encrypted MAC>
+(B<EMAC>). Unlike B<HMAC>, which reuses an existing one-way hash
+function, such as B<MD5>, B<SHA-1> or B<RIPEMD-160>, DMAC reuses an
 existing block cipher to produce a secure B<message authentication
 code> (B<MAC>).
 
@@ -170,17 +138,17 @@ in the paper, ``CBC MAC for Real-Time Data Sources'' by Erez Petrank
 and Charles Rackoff. The security can be proved on the assumption that
 the underlying block cipher is pseudo-random.
 
-The performance and key-agility of EMAC are reasonable. EMAC is
+The performance and key-agility of DMAC are reasonable. DMAC is
 preferable for short messages because the block length is smaller
-compared to the schemes based on a hash function. EMAC is also chosen
+compared to the schemes based on a hash function. DMAC is also chosen
 as one of the NESSIE winners for Message Authentication Codes, along
 with B<UMAC>, B<TTMAC> and B<HMAC>. The current NESSIE specification
 chooses the B<AES> as block cipher.
 
 Also specified in the paper by Petrank and Rackoff is the construction
 of two encryption keys from a single key. The first subkey is derived
-by encrypting `0' (zero) using the original secret key. To produce the
-second subkey, a `1' (one) is encrypted using the original secret key.
+by encrypting "0" (zero) using the original secret key. To produce the
+second subkey, a "1" (one) is encrypted using the original secret key.
 The first subkey is used in CBC mode to encrypt the entire message. The
 last ciphertext block is then re-encrypted with the second subkey. The
 result is a MAC whose length is equal to the block length of the cipher
@@ -192,12 +160,7 @@ The module B<Crypt::CBC> is required, plus any block cipher that is
 capable of returning its block size when queried. B<RC5> is not
 supported, however, because its block size is variable.
 
-B<MIME::Base64> is also required for base64 encoding of output.
-
-=head1 LICENSE
-
-This program is free software; you can redistribute it or modify it
-under the terms of the GNU General Public License. 
+B<MIME::Base64> is required if a base64 encoding of output is desired.
 
 =head1 AUTHOR
 
